@@ -13,21 +13,22 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import warnings
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
+import warnings
 
-from google.api_core import gapic_v1
-from google.api_core import grpc_helpers_async
+from google.api_core import gapic_v1, grpc_helpers_async
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
 
-from google.cloud.bigquery_migration_v2.types import migration_entities
-from google.cloud.bigquery_migration_v2.types import migration_service
-from google.protobuf import empty_pb2  # type: ignore
-from .base import MigrationServiceTransport, DEFAULT_CLIENT_INFO
+from google.cloud.bigquery_migration_v2.types import (
+    migration_entities,
+    migration_service,
+)
+
+from .base import DEFAULT_CLIENT_INFO, MigrationServiceTransport
 from .grpc import MigrationServiceGrpcTransport
 
 
